@@ -132,6 +132,9 @@ function lsmr end
     workspace = lsmr!(workspace::LsmrWorkspace, A, b; kwargs...)
 
 In this call, `kwargs` are keyword arguments of [`lsmr`](@ref).
+The keyword argument `window` is the only exception.
+It is only supported by [`lsmr`](@ref) and is required to create a `LsmrWorkspace`.
+It cannot be changed later.
 
 See [`LsmrWorkspace`](@ref) for instructions on how to create the `workspace`.
 
@@ -168,7 +171,7 @@ args_lsmr = (:A, :b)
 kwargs_lsmr = (:M, :N, :ldiv, :sqd, :λ, :radius, :etol, :axtol, :btol, :conlim, :atol, :rtol, :itmax, :timemax, :verbose, :history, :callback, :iostream)
 
 @eval begin
-  function lsmr!(workspace :: LsmrWorkspace{T,FC,S}, $(def_args_lsmr...); $(def_kwargs_lsmr...)) where {T <: AbstractFloat, FC <: FloatOrComplex{T}, S <: AbstractVector{FC}}
+  function lsmr!(workspace :: LsmrWorkspace{T,FC,Sm,Sn}, $(def_args_lsmr...); $(def_kwargs_lsmr...)) where {T <: AbstractFloat, FC <: FloatOrComplex{T}, Sm <: AbstractVector{FC}, Sn <: AbstractVector{FC}}
 
     # Timer
     start_time = time_ns()
@@ -189,14 +192,14 @@ kwargs_lsmr = (:M, :N, :ldiv, :sqd, :λ, :radius, :etol, :axtol, :btol, :conlim,
 
     # Check type consistency
     eltype(A) == FC || @warn "eltype(A) ≠ $FC. This could lead to errors or additional allocations in operator-vector products."
-    ktypeof(b) == S || error("ktypeof(b) must be equal to $S")
+    ktypeof(b) == Sm || error("ktypeof(b) must be equal to $Sm")
 
     # Compute the adjoint of A
     Aᴴ = A'
 
     # Set up workspace.
-    allocate_if(!MisI, workspace, :u, S, workspace.Av)  # The length of u is m
-    allocate_if(!NisI, workspace, :v, S, workspace.x)   # The length of v is n
+    allocate_if(!MisI, workspace, :u, Sm, workspace.Av)  # The length of u is m
+    allocate_if(!NisI, workspace, :v, Sn, workspace.x)   # The length of v is n
     x, Nv, Aᴴu, h, hbar = workspace.x, workspace.Nv, workspace.Aᴴu, workspace.h, workspace.hbar
     Mu, Av, err_vec, stats = workspace.Mu, workspace.Av, workspace.err_vec, workspace.stats
     rNorms, ArNorms = stats.residuals, stats.Aresiduals
