@@ -137,7 +137,7 @@
       resid = norm(r) / norm(rhs)
       @test(resid ≤ tricg_tol)
 
-      # Test specific brekdowns
+      # Test specific breakdowns
       A, b, c = ssy_mo_breakdown2(FC)
       K = [I A; A' -I]
       d = [b; c]
@@ -166,6 +166,18 @@
         @test sqrt(dot(r, inv(H) * r)) / sqrt(dot([b; c], inv(H) * [b; c])) ≤ tricg_tol
       end
 
+      # Test different types for b and c
+      A, b, _ = saddle_point(FC=FC)
+      (x, y, stats) = tricg(A, b, -b)
+      c = TestVector(-b)
+      workspace = TricgWorkspace(KrylovConstructor(b, c))
+      @test typeof(workspace.x) === typeof(b)
+      @test typeof(workspace.y) === typeof(c)
+      tricg!(workspace, A, b, c)
+      xt, yt = workspace.x, workspace.y
+      @test typeof(xt) === typeof(b)
+      @test typeof(yt) === typeof(c)
+
       for transpose ∈ (false, true)
         A, b, c = ssy_mo_breakdown(transpose)
 
